[![Documentation Status](https://readthedocs.org/projects/mcwb/badge/?version=latest)](https://mcwb.readthedocs.io/en/latest/?badge=latest)
[![Quality Gate Status](https://sonarqube.richard-neumann.de/api/project_badges/measure?project=mcwb&metric=alert_status)](https://sonarqube.richard-neumann.de/dashboard?id=mcwb)

# mcwb
A Minecraft world builder library.

## Requirements
`mcwb` requires Python 3.8 or higher. It also depends on [mcipc](https://github.com/conqp/mcipc).  
If you install `mcwb` via `pip`, it will automatically be installed as a dependency.

## Documentation
Documentation is available on [readthedocs](https://mcwb.readthedocs.io/en/latest).

## Quick start

Install mcwb from the [AUR](https://aur.archlinux.org/packages/python-mcwb/) or via:

    pip install mcwb

## Credits
Many thanks to all contributers to the [Minecraft Wiki](https://minecraft.gamepedia.com/) and the [Wiki.vg](https://wiki.vg/Main_Page).

## License
Copyright (C) 2018-2021 Richard Neumann <mail at richard dash neumann period de>

mcwb is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

mcwb is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with mcwb.  If not, see <http://www.gnu.org/licenses/>.

## Legal
Minecraft content and materials are trademarks and copyrights of
Mojang and its licensors. All rights reserved.
This program is free software and is not affiliated with Mojang.
